"""
    HW Mux Reservation System

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1.6
    Generated by: https://openapi-generator.tech
"""


import unittest

import hwmux_client
from hwmux_client.api.groups_api import GroupsApi  # noqa: E501


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_groups_available_list(self):
        """Test case for groups_available_list

        """
        pass

    def test_groups_create(self):
        """Test case for groups_create

        """
        pass

    def test_groups_create_with_devices_create(self):
        """Test case for groups_create_with_devices_create

        """
        pass

    def test_groups_destroy(self):
        """Test case for groups_destroy

        """
        pass

    def test_groups_list(self):
        """Test case for groups_list

        """
        pass

    def test_groups_my_list(self):
        """Test case for groups_my_list

        """
        pass

    def test_groups_partial_update(self):
        """Test case for groups_partial_update

        """
        pass

    def test_groups_release_by_name_update(self):
        """Test case for groups_release_by_name_update

        """
        pass

    def test_groups_release_update(self):
        """Test case for groups_release_update

        """
        pass

    def test_groups_reserve_by_name_update(self):
        """Test case for groups_reserve_by_name_update

        """
        pass

    def test_groups_reserve_update(self):
        """Test case for groups_reserve_update

        """
        pass

    def test_groups_retrieve(self):
        """Test case for groups_retrieve

        """
        pass

    def test_groups_update(self):
        """Test case for groups_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
