"""
    HW Mux Reservation System

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import hwmux_client
from hwmux_client.api.permissions_api import PermissionsApi  # noqa: E501


class TestPermissionsApi(unittest.TestCase):
    """PermissionsApi unit test stubs"""

    def setUp(self):
        self.api = PermissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_permissions_groups_create(self):
        """Test case for permissions_groups_create

        """
        pass

    def test_permissions_groups_device_groups_create(self):
        """Test case for permissions_groups_device_groups_create

        """
        pass

    def test_permissions_groups_device_groups_destroy(self):
        """Test case for permissions_groups_device_groups_destroy

        """
        pass

    def test_permissions_groups_device_groups_list(self):
        """Test case for permissions_groups_device_groups_list

        """
        pass

    def test_permissions_groups_device_groups_partial_update(self):
        """Test case for permissions_groups_device_groups_partial_update

        """
        pass

    def test_permissions_groups_device_groups_update(self):
        """Test case for permissions_groups_device_groups_update

        """
        pass

    def test_permissions_groups_devices_create(self):
        """Test case for permissions_groups_devices_create

        """
        pass

    def test_permissions_groups_devices_destroy(self):
        """Test case for permissions_groups_devices_destroy

        """
        pass

    def test_permissions_groups_devices_list(self):
        """Test case for permissions_groups_devices_list

        """
        pass

    def test_permissions_groups_devices_partial_update(self):
        """Test case for permissions_groups_devices_partial_update

        """
        pass

    def test_permissions_groups_devices_update(self):
        """Test case for permissions_groups_devices_update

        """
        pass

    def test_permissions_groups_labels_create(self):
        """Test case for permissions_groups_labels_create

        """
        pass

    def test_permissions_groups_labels_destroy(self):
        """Test case for permissions_groups_labels_destroy

        """
        pass

    def test_permissions_groups_labels_list(self):
        """Test case for permissions_groups_labels_list

        """
        pass

    def test_permissions_groups_labels_partial_update(self):
        """Test case for permissions_groups_labels_partial_update

        """
        pass

    def test_permissions_groups_labels_update(self):
        """Test case for permissions_groups_labels_update

        """
        pass

    def test_permissions_groups_list(self):
        """Test case for permissions_groups_list

        """
        pass

    def test_permissions_groups_retrieve(self):
        """Test case for permissions_groups_retrieve

        """
        pass

    def test_permissions_groups_users_create(self):
        """Test case for permissions_groups_users_create

        """
        pass

    def test_permissions_groups_users_destroy(self):
        """Test case for permissions_groups_users_destroy

        """
        pass


if __name__ == '__main__':
    unittest.main()
