"""
    HW Mux Reservation System

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1.6
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import hwmux_client
from hwmux_client.model.event_enum import EventEnum


class TestEventEnum(unittest.TestCase):
    """EventEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEventEnum(self):
        """Test EventEnum"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EventEnum()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
